@@ -30,27 +30,24 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-$text = ($this->task == 'edit' ? JText::_('Edit') : JText::_('New'));
-JToolBarHelper::title(JText::_('Publication Category') . ': [ ' . $text . ' ]', 'addedit.png');
+$text = ($this->task == 'edit' ? JText::_('JACTION_EDIT') : JText::_('JACTION_CREATE'));
+JToolBarHelper::title(JText::_('COM_PUBLICATIONS_PUBLICATION_CATEGORY') . ': [ ' . $text . ' ]', 'addedit.png');
 JToolBarHelper::save();
 JToolBarHelper::cancel();
 
 $dcTypes = array(
 	'Collection' , 'Dataset' , 'Event' , 'Image' ,
- 	'InteractivePublication' , 'MovingImage' , 'PhysicalObject' ,
-    'Service' , 'Software' , 'Sound' , 'StillImage' , 'Text');
+	'InteractivePublication' , 'MovingImage' , 'PhysicalObject' ,
+	'Service' , 'Software' , 'Sound' , 'StillImage' , 'Text'
+);
 
-$paramsClass = 'JParameter';
-if (version_compare(JVERSION, '1.6', 'ge'))
-{
-	$paramsClass = 'JRegistry';
-}
+$params = new JRegistry($this->row->params);
 
-$params = new $paramsClass($this->row->params);
+JHTML::_('behavior.framework', true);
 
 ?>
 <script type="text/javascript">
-function submitbutton(pressbutton) 
+function submitbutton(pressbutton)
 {
 	submitform( pressbutton );
 	return;
@@ -60,45 +57,42 @@ function submitbutton(pressbutton)
 <form action="index.php" method="post" id="item-form" name="adminForm">
 	<div class="col width-50 fltlft">
 		<fieldset class="adminform">
-			<legend><span><?php echo JText::_('Category Information'); ?></span></legend>
-
-			<table class="admintable">
-				<tbody>
-					<tr>
-						<td class="key"><label for="field-name"><?php echo JText::_('Name'); ?>:<span class="required">*</span></label></td>
-						<td>
-							<input type="text" name="prop[name]" id="field-name" size="55" maxlength="100" value="<?php echo $this->escape($this->row->name); ?>" />
-						</td>
-					</tr>
-					<tr>
-						<td class="key"><label for="field-alias"><?php echo JText::_('Alias'); ?>:</label></td>
-						<td>
-							<input type="text" name="prop[alias]" id="field-alias" size="55" maxlength="100" value="<?php echo $this->escape($this->row->alias); ?>" />
-						</td>
-					</tr>
-					<tr>
-						<td class="key"><label for="field-url_alias"><?php echo JText::_('URL Alias'); ?>:</label></td>
-						<td>
-							<input type="text" name="prop[url_alias]" id="field-url_alias" size="55" maxlength="100" value="<?php echo $this->escape($this->row->url_alias); ?>" />
-						</td>
-					</tr>
-					<tr>
-						<td class="key"><label for="field-dc_type"><?php echo JText::_('dc:type'); ?>:</label></td>
-						<td>
-							<select name="prop[dc_type]" id="field-dc_type">
-							<?php foreach ($dcTypes as $dct) { ?>
-							<option value="<?php echo $dct; ?>" <?php if ($this->escape($this->row->dc_type) == $dct) { echo 'selected="selected"'; } ?>><?php echo $dct; ?></option>
-							<?php } ?>
-							</select>
-							<span class="hint"><?php echo JText::_('DublinCoreMetaData type'); ?></span>
-						</td>
-					</tr>
-					<tr>
-						<td class="key"><label><?php echo JText::_('Description'); ?>:</label></td>
-						<td><input type="text" name="prop[description]" id="field-description" size="55" maxlength="255" value="<?php echo $this->escape($this->row->description); ?>" /></td>
-					</tr>
-				</tbody>
-			</table>
+			<legend><span><?php echo JText::_('COM_PUBLICATIONS_CATEGORY_INFORMATION'); ?></span></legend>
+<?php if ($this->row->id) { ?>
+	<table>
+		<tbody>
+			<tr>
+				<th><?php echo JText::_('ID'); ?></th>
+				<td><?php echo $this->row->id; ?></td>
+			</tr>
+		</tbody>
+	</table>
+<?php } ?>
+			<div class="input-wrap">
+				<label for="field-name"><?php echo JText::_('COM_PUBLICATIONS_FIELD_NAME'); ?>:<span class="required"><?php echo JText::_('JOPTION_REQUIRED'); ?></span></label>
+				<input type="text" name="prop[name]" id="field-name" maxlength="100" value="<?php echo $this->escape($this->row->name); ?>" />
+			</div>
+			<div class="input-wrap">
+				<label for="field-alias"><?php echo JText::_('COM_PUBLICATIONS_FIELD_ALIAS'); ?>:</label>
+				<input type="text" name="prop[alias]" id="field-alias" maxlength="100" value="<?php echo $this->escape($this->row->alias); ?>" />
+			</div>
+			<div class="input-wrap">
+				<label for="field-url_alias"><?php echo JText::_('COM_PUBLICATIONS_FIELD_URL_ALIAS'); ?>:</label>
+				<input type="text" name="prop[url_alias]" id="field-url_alias" maxlength="100" value="<?php echo $this->escape($this->row->url_alias); ?>" />
+			</div>
+			<div class="input-wrap" data-hint="<?php echo JText::_('COM_PUBLICATIONS_FIELD_DUBLIN_CORE'); ?>">
+				<label for="field-dc_type"><?php echo JText::_('COM_PUBLICATIONS_FIELD_DC_TYPE'); ?>:</label>
+				<select name="prop[dc_type]" id="field-dc_type">
+					<?php foreach ($dcTypes as $dct) { ?>
+					<option value="<?php echo $dct; ?>" <?php if ($this->escape($this->row->dc_type) == $dct) { echo 'selected="selected"'; } ?>><?php echo $dct; ?></option>
+					<?php } ?>
+				</select>
+				<span class="hint"><?php echo JText::_('COM_PUBLICATIONS_FIELD_DUBLIN_CORE'); ?></span>
+			</div>
+			<div class="input-wrap">
+				<label for="field-description"><?php echo JText::_('COM_PUBLICATIONS_FIELD_DESCRIPTION'); ?>:</label>
+				<input type="text" name="prop[description]" id="field-description" size="55" maxlength="255" value="<?php echo $this->escape($this->row->description); ?>" />
+			</div>
 
 			<input type="hidden" name="prop[id]" value="<?php echo $this->row->id; ?>" />
 			<input type="hidden" name="option" value="<?php echo $this->option; ?>" />
@@ -107,83 +101,72 @@ function submitbutton(pressbutton)
 		</fieldset>
 	</div>
 	<div class="col width-50 fltrt">
-	  <fieldset class="adminform">
-		<legend><span><?php echo JText::_('Item Configuration'); ?></span></legend>
-		<table class="admintable">
-			<tbody>
-				<tr>
-					<td class="key"><?php echo JText::_('ID'); ?></td>
-					<td><?php echo $this->row->id; ?></td>
-				</tr>
-				<tr>
-					<td class="key"><?php echo JText::_('Status'); ?></td>
-					<td>
-						<label class="block"><input class="option" name="prop[state]" type="radio" value="1" <?php echo $this->row->state == 1 ? 'checked="checked"' : ''; ?> /> <?php echo JText::_('Active'); ?>
-						</label>
-						<label class="block"><input class="option" name="prop[state]" type="radio" value="0" <?php echo $this->row->state != 1 ? 'checked="checked"' : ''; ?> /> <?php echo JText::_('Inactive'); ?>
-						</label>
-					</td>
-				</tr>
-				<tr>
-					<td class="key"><?php echo JText::_('Contributable'); ?></td>
-					<td>
-						<span class="hint"><?php echo JText::_('Offer category as a catalogue choice for new publications?'); ?></span>
-						<label class="block"><input class="option" name="prop[contributable]" type="radio" value="1" <?php echo $this->row->contributable == 1 ? 'checked="checked"' : ''; ?> /> <?php echo JText::_('Yes'); ?>
-						</label>
-						<label class="block"><input class="option" name="prop[contributable]" type="radio" value="0" <?php echo $this->row->contributable == 0 ? 'checked="checked"' : ''; ?> /> <?php echo JText::_('No'); ?>
-						</label>
-					</td>
-				</tr>
-			</tbody>
-		</table>
+
+		<fieldset class="adminform">
+			<legend><span><?php echo JText::_('COM_PUBLICATIONS_FIELD_ITEM_CONFIG'); ?></span></legend>
+
+			<fieldset>
+				<legend><?php echo JText::_('COM_PUBLICATIONS_FIELD_STATUS'); ?></legend>
+
+				<div class="input-wrap">
+					<input class="option" name="prop[state]" id="field-state1" type="radio" value="1" <?php echo $this->row->state == 1 ? 'checked="checked"' : ''; ?> />
+					<label for="field-state1"><?php echo JText::_('COM_PUBLICATIONS_STATUS_ACTIVE'); ?></label>
+					<br />
+					<input class="option" name="prop[state]" id="field-state0" type="radio" value="0" <?php echo $this->row->state != 1 ? 'checked="checked"' : ''; ?> />
+					<label for="field-state0"><?php echo JText::_('COM_PUBLICATIONS_STATUS_INACTIVE'); ?></label>
+				</div>
+			</fieldset>
+			<fieldset>
+				<legend><?php echo JText::_('COM_PUBLICATIONS_FIELD_CONTRIBUTABLE'); ?></legend>
+				<div class="input-wrap" data-hint="<?php echo JText::_('COM_PUBLICATIONS_FIELD_CONTRIBUTABLE_HINT'); ?>">
+					<span class="hint"><?php echo JText::_('COM_PUBLICATIONS_FIELD_CONTRIBUTABLE_HINT'); ?></span>
+
+					<input class="option" name="prop[contributable]" id="field-contributable1" type="radio" value="1" <?php echo $this->row->contributable == 1 ? 'checked="checked"' : ''; ?> />
+					<label for="field-contributable1"><?php echo JText::_('JYES'); ?></label>
+					<br />
+					<input class="option" name="prop[contributable]" id="field-contributable0" type="radio" value="0" <?php echo $this->row->contributable == 0 ? 'checked="checked"' : ''; ?> />
+					<label for="field-contributable0"><?php echo JText::_('JNO'); ?></label>
+				</div>
+			</fieldset>
 		</fieldset>
 	</div>
 	<div class="clr"></div>
+
 	<div class="col width-50 fltrt">
 		<fieldset class="adminform">
 			<legend><span><?php echo JText::_('COM_PUBLICATIONS_CATS_MASTER_TYPE_CONFIG'); ?></span></legend>
-			
-			<table class="admintable">
-				<tbody>
-					<?php foreach ($this->types as $mt) { ?>
-					<tr>
-						<td class="key"><?php echo $mt; ?></td>
-						<td>
-							<label class="block"><input class="option" name="params[type_<?php echo $mt; ?>]" type="radio" value="1" <?php echo ($params->get('type_'.$mt, 1) == 1) ? ' checked="checked"':''; ?> /> <?php echo 'include as choice'; ?></label>
-						</td>
-						<td>
-							<label class="block"><input class="option" name="params[type_<?php echo $mt; ?>]" type="radio" value="0" <?php echo ($params->get('type_'.$mt, 1) == 0) ? ' checked="checked"':''; ?> /> <?php echo 'not applicable'; ?></label>
-						</td>
-					</tr>
-				<?php } ?>	
-				</tbody>
-			</table>
+
+			<?php foreach ($this->types as $mt) { ?>
+				<fieldset>
+					<legend><?php echo $mt; ?></legend>
+					<div class="input-wrap">
+						<input class="option" name="params[type_<?php echo $mt; ?>]" id="field-type_<?php echo $mt; ?>1" type="radio" value="1" <?php echo ($params->get('type_'.$mt, 1) == 1) ? ' checked="checked"':''; ?> />
+						<label for="field-type_<?php echo $mt; ?>1"><?php echo  JText::_('COM_PUBLICATIONS_INCLUDE_CHOICE'); ?></label>
+						<br />
+						<input class="option" name="params[type_<?php echo $mt; ?>]" id="field-type_<?php echo $mt; ?>0" type="radio" value="0" <?php echo ($params->get('type_'.$mt, 1) == 0) ? ' checked="checked"':''; ?> />
+						<label for="field-type_<?php echo $mt; ?>0"><?php echo JText::_('COM_PUBLICATIONS_NOT_APPLICABLE'); ?></label>
+					</div>
+				</fieldset>
+			<?php } ?>
 		</fieldset>
 	</div>
 	<div class="col width-50 ltlft">
 		<fieldset class="adminform">
-			<legend><span><?php echo JText::_('Plugins'); ?></span></legend>
+			<legend><span><?php echo JText::_('COM_PUBLICATIONS_PLUGINS'); ?></span></legend>
 
 			<table class="admintable">
 				<thead>
 					<tr>
-						<th><?php echo JText::_('Plugin'); ?></th>
-						<th colspan="2"><?php echo JText::_('Active'); ?></th>
+						<th><?php echo JText::_('COM_PUBLICATIONS_PLUGIN'); ?></th>
+						<th colspan="2"><?php echo JText::_('COM_PUBLICATIONS_STATUS_ACTIVE'); ?></th>
 					</tr>
 				</thead>
 				<tbody>
-				<?php 
+				<?php
 				$database = JFactory::getDBO();
-				if (version_compare(JVERSION, '1.6', 'ge'))
-				{
-					$database->setQuery( "SELECT * FROM #__extensions WHERE `type`='plugin' AND `folder`='publications'" );
-				}
-				else
-				{
-					$database->setQuery( "SELECT * FROM #__plugins WHERE `folder`='publications'" );
-				}
-				$plugins = $database->loadObjectList();
-				if ($plugins)
+				$database->setQuery( "SELECT * FROM `#__extensions` WHERE `type`='plugin' AND `folder`='publications'" );
+
+				if ($plugins = $database->loadObjectList())
 				{
 					$found = array();
 					foreach ($plugins as $plugin)
@@ -206,13 +189,14 @@ function submitbutton(pressbutton)
 						</tr>
 						<?php
 					}
-				}		
+				}
 				?>
 				</tbody>
 			</table>
 		</fieldset>
 	</div>
 	<div class="clr"></div>
+	<?php if (!$this->config->get('curation', 0)) { ?>
 		<div class="col width-100">
 		<fieldset class="adminform">
 			<legend><span><?php echo JText::_('COM_PUBLICATIONS_TYPES_CUSTOM_FIELDS'); ?></span></legend>
@@ -233,14 +217,15 @@ function submitbutton(pressbutton)
 					<tr>
 						<td colspan="<?php echo '5';//($this->row->id) ? '5' : '4'; ?>">
 							<button id="add-custom-field" href="#addRow">
-								<span><?php echo JText::_('+ Add new row'); ?></span>
+								<span><?php echo JText::_('COM_PUBLICATIONS_ADD_ROW'); ?></span>
 							</button>
 						</td>
 					</tr>
 				</tfoot>
 				<tbody id="field-items">
-				<?php 
-				include_once(JPATH_ROOT . DS . 'components' . DS . 'com_publications' . DS . 'models' . DS . 'elements.php');
+				<?php
+				include_once(JPATH_ROOT . DS . 'components' . DS . 'com_publications'
+					. DS . 'models' . DS . 'elements.php');
 				$elements = new PublicationsElements('', $this->row->customFields);
 				$schema = $elements->getSchema();
 
@@ -285,7 +270,7 @@ function submitbutton(pressbutton)
 						</td>
 						<td>
 							<select name="fields[<?php echo $i; ?>][type]" id="fields-<?php echo $i; ?>-type">
-								<optgroup label="<?php echo JText::_('Common'); ?>">
+								<optgroup label="<?php echo JText::_('COM_PUBLICATIONS_COMMON'); ?>">
 									<option value="text"<?php echo ($field->type == 'text') ? ' selected="selected"':''; ?>><?php echo JText::_('COM_PUBLICATIONS_TYPES_TEXT'); ?></option>
 									<option value="textarea"<?php echo ($field->type == 'textarea') ? ' selected="selected"':''; ?>><?php echo JText::_('COM_PUBLICATIONS_TYPES_TEXTAREA'); ?></option>
 									<option value="list"<?php echo ($field->type == 'list') ? ' selected="selected"':''; ?>><?php echo JText::_('COM_PUBLICATIONS_TYPES_LIST'); ?></option>
@@ -293,10 +278,10 @@ function submitbutton(pressbutton)
 									<option value="checkbox"<?php echo ($field->type == 'checkbox') ? ' selected="selected"':''; ?>><?php echo JText::_('COM_PUBLICATIONS_TYPES_CHECKBOX'); ?></option>
 									<option value="hidden"<?php echo ($field->type == 'hidden') ? ' selected="selected"':''; ?>><?php echo JText::_('COM_PUBLICATIONS_TYPES_HIDDEN'); ?></option>
 								</optgroup>
-								<optgroup label="<?php echo JText::_('Pre-defined'); ?>">
+								<optgroup label="<?php echo JText::_('COM_PUBLICATIONS_PRE_DEFINED'); ?>">
 									<option value="date"<?php echo ($field->type == 'date') ? ' selected="selected"':''; ?>><?php echo JText::_('Date'); ?></option>
 									<option value="geo"<?php echo ($field->type == 'geo') ? ' selected="selected"':''; ?>><?php echo JText::_('Geo Location'); ?></option>
-									<option value="languages"<?php echo ($field->type == 'languages') ? ' selected="selected"':''; ?>><?php echo JText::_('Language List'); ?></option>
+									<option value="languages"<?php echo ($field->type == 'languages') ? ' selected="selected"':''; ?>><?php echo JText::_('COM_PUBLICATIONS_LANGUAGE_LIST'); ?></option>
 								</optgroup>
 							</select>
 						</td>
@@ -314,9 +299,9 @@ function submitbutton(pressbutton)
 				</tbody>
 			</table>
 
-			<script type="text/javascript" src="/media/system/js/jquery.js"></script> 
-			<script type="text/javascript" src="/media/system/js/jquery.noconflict.js"></script> 
-			<script type="text/javascript" src="/media/system/js/jquery.ui.js"></script> 
+			<!-- <script type="text/javascript" src="/media/system/js/jquery.js"></script>
+			<script type="text/javascript" src="/media/system/js/jquery.noconflict.js"></script>
+			<script type="text/javascript" src="/media/system/js/jquery.ui.js"></script>  -->
 			<script type="text/javascript">
 				if (!jq) {
 					var jq = $;
@@ -340,10 +325,10 @@ function submitbutton(pressbutton)
 							replaceme = null;
 
 						var newField = newNode.childNodes;
-						for (var i=0;i<newField.length;i++) 
+						for (var i=0;i<newField.length;i++)
 						{
 							var inputs = newField[i].childNodes;
-							for (var k=0;k<inputs.length;k++) 
+							for (var k=0;k<inputs.length;k++)
 							{
 								var theName = inputs[k].name;
 								if (theName) {
@@ -377,7 +362,7 @@ function submitbutton(pressbutton)
 
 						// Make a clone of the clone. Why? Because IE 8 is dumb.
 						// IE still retains a reference to the original object for change events
-						// So, when calling onChange, the event gets fired for the clone AND the 
+						// So, when calling onChange, the event gets fired for the clone AND the
 						// original. Cloning the clone seems to fix this.
 						if (replaceme) {
 							var replace = jq(replaceme);
@@ -398,10 +383,10 @@ function submitbutton(pressbutton)
 						var newNode = tbody.rows[0].cloneNode(true);
 
 						var newField = newNode.childNodes;
-						for (var i=0;i<newField.length;i++) 
+						for (var i=0;i<newField.length;i++)
 						{
 							var inputs = newField[i].childNodes;
-							for (var k=0;k<inputs.length;k++) 
+							for (var k=0;k<inputs.length;k++)
 							{
 								var theName = inputs[k].name;
 								if (theName) {
@@ -488,5 +473,6 @@ function submitbutton(pressbutton)
 		</fieldset>
 		</div>
 		<div class="clr"></div>
+		<?php } ?>
 	<?php echo JHTML::_('form.token'); ?>
 </form>
\ No newline at end of file
