@@ -31,8 +31,6 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-require_once(JPATH_ROOT . DS . 'components' . DS . 'com_courses' . DS . 'models' . DS . 'course.php');
-
 /**
  * Courses controller class
  */
@@ -40,7 +38,7 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 {
 	/**
 	 * Execute a task
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function execute()
@@ -55,7 +53,7 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 
 	/**
 	 * Method to set the document path
-	 * 
+	 *
 	 * @param      array $course_pages List of roup pages
 	 * @return     void
 	 */
@@ -63,29 +61,21 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 	{
 		$pathway = JFactory::getApplication()->getPathway();
 
-		if (count($pathway->getPathWay()) <= 0) 
+		if (count($pathway->getPathWay()) <= 0)
 		{
 			$pathway->addItem(
 				JText::_(strtoupper($this->_option)),
 				'index.php?option=' . $this->_option
 			);
 		}
-		if ($this->course->exists()) 
+		if ($this->course->exists())
 		{
 			$pathway->addItem(
 				stripslashes($this->course->get('title')),
 				'index.php?option=' . $this->_option . '&gid=' . $this->course->get('alias')
 			);
-
-			/*if ($this->active) 
-			{
-				$pathway->addItem(
-					JText::_(strtoupper($this->_option) . '_' . strtoupper($this->active)), 
-					'index.php?option=' . $this->_option . '&gid=' . $this->course->get('alias') . '&active=' . $this->active
-				);
-			}*/
 		}
-		else 
+		else
 		{
 			$pathway->addItem(
 				JText::_(strtoupper($this->_option) . '_' . strtoupper($this->_task)),
@@ -96,7 +86,7 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 
 	/**
 	 * Method to build and set the document title
-	 * 
+	 *
 	 * @return     void
 	 */
 	protected function _buildTitle()
@@ -104,13 +94,13 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 		//set title used in view
 		$this->_title = JText::_(strtoupper($this->_option));
 
-		if ($this->course->exists()) 
+		if ($this->course->exists())
 		{
 			$this->_title .= ': ' . stripslashes($this->course->get('title'));
 		}
 		else
 		{
-			if ($this->_task && $this->_task != 'intro') 
+			if ($this->_task && $this->_task != 'intro')
 			{
 				$this->_title .= JText::_(strtoupper($this->_option . '_' . $this->_task));
 			}
@@ -123,7 +113,7 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 
 	/**
 	 * Redirect to login page
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function loginTask($message = '')
@@ -139,23 +129,22 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 
 	/**
 	 * View a course
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function displayTask()
 	{
-		if (!$this->course->access('view'))
+		if (!$this->course->isPublished() && !$this->course->isDraft())
 		{
 			JError::raiseError(404, JText::_('COM_COURSES_NO_COURSE_FOUND'));
 			return;
 		}
 
-		// Push some needed styles to the template
-		// Pass in course type to include special css for paying courses
-		$this->_getStyles($this->_option, $this->_controller . '.css');
-
-		// Push some needed scripts to the template
-		$this->_getScripts();
+		if (!$this->course->access('view'))
+		{
+			JError::raiseError(404, JText::_('COM_COURSES_NO_COURSE_FOUND'));
+			return;
+		}
 
 		// Build the title
 		$this->_buildTitle();
@@ -210,7 +199,7 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 
 	/**
 	 * Show a form for editing a course
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function newTask()
@@ -220,7 +209,7 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 
 	/**
 	 * Show a form for editing a course
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function editTask($model=null)
@@ -228,9 +217,9 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 		$this->view->setLayout('edit');
 
 		// Check if they're logged in
-		if ($this->juser->get('guest')) 
+		if ($this->juser->get('guest'))
 		{
-			$this->loginTask(JText::_('You must be logged in to edit or create courses.'));
+			$this->loginTask(JText::_('COM_COURSES_NOT_LOGGEDIN'));
 			return;
 		}
 
@@ -240,40 +229,34 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 		// Build pathway
 		$this->_buildPathway();
 
-		// Push some needed styles to the template
-		$this->_getStyles($this->_option, $this->_controller . '.css');
-
-		// Push some needed scripts to the template
-		$this->_getScripts('assets/js/' . $this->_name);
-
 		if (is_object($model))
 		{
 			$this->course = $model;
 		}
 
-		if ($this->_task != 'new') 
+		if ($this->_task != 'new')
 		{
 			// Ensure we found the course info
-			if (!$this->course->exists()) 
+			if (!$this->course->exists())
 			{
 				JError::raiseError(404, JText::_('COM_COURSES_NO_COURSE_FOUND'));
 				return;
 			}
 
 			// Check authorization
-			if (!$this->course->access('edit')) 
+			if (!$this->course->access('edit'))
 			{
 				JError::raiseError(403, JText::_('COM_COURSES_NOT_AUTH'));
 				return;
 			}
 
-			$this->view->title = 'Edit Course: ' . $this->course->get('title');
-		} 
-		else 
+			$this->view->title = JText::_('COM_COURSES_EDIT_COURSE') . ': ' . $this->course->get('title');
+		}
+		else
 		{
 			$this->course->set('state', 3);
 
-			$this->view->title = 'Create New Course';
+			$this->view->title = JText::_('COM_COURSES_NEW_COURSE');
 		}
 
 		//get directory for course file uploads
@@ -290,29 +273,17 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 			$this->view->lid = time() . rand(0, 1000);
 		}
 
-		// Get the course's interests (tags)
-		//$gt = new CoursesTags($this->database);
-		//$this->view->tags = $gt->get_tag_string($this->course->get('id'));
-
-		/*if ($this->course) 
-		{
-			$course = $this->course;
-			$tags  = $this->tags;
-		}*/
-
 		// Output HTML
-		//$this->view->title  = $title;
 		$this->view->course = $this->course;
-		//$this->view->tags   = $tags;
 		$this->view->juser  = $this->juser;
-		//$this->view->lid    = $lid;
+
 		$this->view->notifications = ($this->getComponentMessage()) ? $this->getComponentMessage() : array();
 		$this->view->display();
 	}
 
 	/**
 	 * Save a course
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function saveTask()
@@ -321,9 +292,9 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 		JRequest::checkToken() or jexit('Invalid Token');
 
 		// Check if they're logged in
-		if ($this->juser->get('guest')) 
+		if ($this->juser->get('guest'))
 		{
-			$this->loginTask('You must be logged in to perform this action.');
+			$this->loginTask(JText::_('COM_COURSES_NOT_LOGGEDIN'));
 			return;
 		}
 
@@ -335,20 +306,20 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 
 		// Is this a new entry or updating?
 		$isNew = false;
-		if (!$course->exists()) 
+		if (!$course->exists())
 		{
 			$isNew = true;
 		}
 
 		// Check authorization
-		if (!$isNew && !$course->access('edit', 'course')) 
+		if (!$isNew && !$course->access('edit', 'course'))
 		{
-			JError::raiseError(403, JText::_('COURSES_NOT_AUTH'));
+			JError::raiseError(403, JText::_('COM_COURSES_NOT_AUTH'));
 			return;
 		}
 
 		// Push back into edit mode if any errors
-		if (!$course->bind($data)) 
+		if (!$course->bind($data))
 		{
 			$this->tags = $tags;
 			$this->addComponentMessage($course->getError(), 'error');
@@ -357,13 +328,13 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 		}
 
 		// Force into draft state
-		if ($isNew) 
+		if ($isNew)
 		{
 			$course->set('state', 3);
 		}
 
 		// Push back into edit mode if any errors
-		if (!$course->store(true)) 
+		if (!$course->store(true))
 		{
 			$this->tags = $tags;
 			$this->addComponentMessage($course->getError(), 'error');
@@ -375,18 +346,8 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 		$tagger->tag_object($this->juser->get('id'), $course->get('id'), $tags, 1);
 
 		// Rename the temporary upload directory if it exist
-		if ($isNew) 
+		if ($isNew)
 		{
-			/*if ($lid != $course->get('id')) 
-			{
-				$config = $this->config;
-				$bp = JPATH_ROOT . DS . trim($this->config->get('uploadpath', '/site/courses'), DS);
-				if (is_dir($bp . DS . $lid)) 
-				{
-					rename($bp . DS . $lid, $bp . DS . $course->get('id'));
-				}
-			}*/
-
 			// Set the creator as a manager
 			$role_id = 0;
 			if ($roles = $course->roles())
@@ -404,13 +365,13 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 		}
 
 		// Show success message to user
-		if ($isNew) 
+		if ($isNew)
 		{
-			$msg = JText::sprintf('You have successfully created the "%s" course.', $course->get('title'));
-		} 
-		else 
+			$msg = JText::sprintf('COM_COURSES_COURSE_CREATED', $course->get('title'));
+		}
+		else
 		{
-			$msg = JText::sprintf('You have successfully updated the "%s" course.', $course->get('title'));
+			$msg = JText::sprintf('COM_COURSES_COURSE_UPDATED', $course->get('title'));
 		}
 
 		// Redirect back to the course page
@@ -422,15 +383,15 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 
 	/**
 	 * Show a form for editing a course
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function instructorsTask()
 	{
 		// Check if they're logged in
-		if ($this->juser->get('guest')) 
+		if ($this->juser->get('guest'))
 		{
-			$this->loginTask(JText::_('You must be logged in to perform this action.'));
+			$this->loginTask(JText::_('COM_COURSES_NOT_LOGGEDIN'));
 			return;
 		}
 
@@ -444,15 +405,15 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 
 	/**
 	 * Show a form for editing a course
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function newofferingTask($offering=null)
 	{
 		// Check if they're logged in
-		if ($this->juser->get('guest')) 
+		if ($this->juser->get('guest'))
 		{
-			$this->loginTask(JText::_('You must be logged in to perform this action.'));
+			$this->loginTask(JText::_('COM_COURSES_NOT_LOGGEDIN'));
 			return;
 		}
 
@@ -470,7 +431,7 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 		$this->view->course = $this->course;
 		$this->view->juser  = $this->juser;
 
-		$this->view->title = JText::_('Create Course Offering');
+		$this->view->title = JText::_('COM_COURSES_NEW_OFFERING');
 		$this->view->notifications = ($this->getComponentMessage()) ? $this->getComponentMessage() : array();
 
 		$this->view->display();
@@ -478,7 +439,7 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 
 	/**
 	 * Show a form for editing a course
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function saveofferingTask()
@@ -487,9 +448,9 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 		JRequest::checkToken() or jexit('Invalid Token');
 
 		// Check if they're logged in
-		if ($this->juser->get('guest')) 
+		if ($this->juser->get('guest'))
 		{
-			$this->loginTask(JText::_('You must be logged in to perform this action.'));
+			$this->loginTask(JText::_('COM_COURSES_NOT_LOGGEDIN'));
 			return;
 		}
 
@@ -501,7 +462,7 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 
 		// Is this a new entry or updating?
 		$isNew = false;
-		if (!$offering->exists()) 
+		if (!$offering->exists())
 		{
 			$isNew = true;
 		}
@@ -510,7 +471,7 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 		$response->success = true;
 
 		// Push back into edit mode if any errors
-		if (!$offering->bind($data)) 
+		if (!$offering->bind($data))
 		{
 			if ($no_html)
 			{
@@ -527,7 +488,7 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 		}
 
 		// Push back into edit mode if any errors
-		if (!$offering->store(true)) 
+		if (!$offering->store(true))
 		{
 			if ($no_html)
 			{
@@ -541,10 +502,10 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 			return;
 		}
 
+		$response->message = JText::_('COM_COURSES_OFFERING_SAVED');
+
 		if ($no_html)
 		{
-			$response->message = JText::_('Offering successfully saved.');
-
 			echo json_encode($response);
 		}
 		else
@@ -552,7 +513,7 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 			// Redirect back to the course page
 			$this->setRedirect(
 				JRoute::_($course->link()),
-				JText::_('Offering successfully saved.')
+				$response->message
 			);
 		}
 	}
@@ -561,7 +522,7 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 	 * Delete a course
 	 * This method initially displays a form for confirming deletion
 	 * then deletes course and associated information upon POST
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function deleteTask()
@@ -573,21 +534,14 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 		$this->_buildPathway();
 
 		// Check if they're logged in
-		if ($this->juser->get('guest')) 
+		if ($this->juser->get('guest'))
 		{
-			$this->loginTask(JText::_('You must be logged in to delete a course.'));
+			$this->loginTask(JText::_('COM_COURSES_NOT_LOGGEDIN'));
 			return;
 		}
 
-		// Ensure we have a course to work with
-		/*if (!$this->course->exists()) 
-		{
-			JError::raiseError(404, JText::_('COM_COURSES_NO_COURSE_ID'));
-			return;
-		}*/
-
 		// Ensure we found the course info
-		if (!$this->course->exists()) 
+		if (!$this->course->exists())
 		{
 			JError::raiseError(404, JText::_('COM_COURSES_NO_COURSE_FOUND'));
 			return;
@@ -600,28 +554,7 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 			return;
 		}
 
-		// Get the course params
-		/*$gparams = new JRegistry($this->course->get('params'));
-
-		// If membership is managed in seperate place disallow action
-		if ($gparams->get('membership_control', 1) == 0) 
-		{
-			$this->setRedirect(
-				JRoute::_('index.php?option=' . $this->_option . '&controller=' . $this->_controller . '&gid=' . $this->course->get('cn')),
-				JText::_('Course membership is not managed in the course interface.'), 
-				'error'
-			);
-			return;
-		}*/
-
-		// Push some needed styles to the template
-		$this->_getStyles();
-
-		// Push some needed scripts to the template
-		$this->_getScripts();
-
 		// Get number of course members
-		//$members  = $this->course->get('members');
 		$managers = $this->course->get('managers');
 
 		// Get plugins
@@ -634,9 +567,9 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 		$msg = trim(JRequest::getVar('msg', '', 'post'));
 
 		// Did they confirm delete?
-		if (!$process || !$confirmdel) 
+		if (!$process || !$confirmdel)
 		{
-			if ($process && !$confirmdel) 
+			if ($process && !$confirmdel)
 			{
 				$this->addComponentMessage(JText::_('COM_COURSES_ERROR_CONFIRM_DELETION'), 'error');
 			}
@@ -646,13 +579,13 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 			// Trigger the functions that delete associated content
 			// Should return logs of what was deleted
 			$logs = $dispatcher->trigger('onCourseDeleteCount', array($course));
-			if (count($logs) > 0) 
+			if (count($logs) > 0)
 			{
 				$log .= '<br />' . implode('<br />', $logs);
 			}
 
 			// Output HTML
-			$this->view->title  = 'Delete Course: ' . $this->course->get('title');
+			$this->view->title  = JText::_('COM_COURSES_DELETE_COURSE') . ': ' . $this->course->get('title');
 			$this->view->course = $course;
 			$this->view->log    = $log;
 			$this->view->msg    = $msg;
@@ -664,11 +597,11 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 		$this->course->set('state', 2);
 
 		// Delete course
-		if (!$this->course->update()) 
+		if (!$this->course->update())
 		{
 			$this->view->setLayout('error');
 			$this->view->title = $title;
-			if ($this->course->getError()) 
+			if ($this->course->getError())
 			{
 				$this->addComponentMessage($this->course->getError(), 'error');
 			}
@@ -683,15 +616,16 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 		$jconfig = JFactory::getConfig();
 
 		// Build the "from" info for e-mails
-		$from = array();
-		$from['name']  = $jconfig->getValue('config.sitename') . ' ' . JText::_(strtoupper($this->_name));
-		$from['email'] = $jconfig->getValue('config.mailfrom');
+		$from = array(
+			'name'  => $jconfig->getValue('config.sitename') . ' ' . JText::_(strtoupper($this->_name)),
+			'email' => $jconfig->getValue('config.mailfrom')
+		);
 
 		// E-mail subject
 		$subject = JText::sprintf('COM_COURSES_SUBJECT_COURSE_DELETED', $gcn);
 
 		// Build the e-mail message
-		$eview = new JView(array(
+		$eview = new \Hubzero\Component\View(array(
 			'name'   => 'emails',
 			'layout' => 'deleted'
 		));
@@ -708,7 +642,7 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 		// Send the message
 		JPluginHelper::importPlugin('xmessage');
 		$dispatcher = JDispatcher::getInstance();
-		if (!$dispatcher->trigger('onSendMessage', array('courses_deleted', $subject, $message, $from, $members, $this->_option))) 
+		if (!$dispatcher->trigger('onSendMessage', array('courses_deleted', $subject, $message, $from, $members, $this->_option)))
 		{
 			$this->addComponentMessage(JText::_('COM_COURSES_ERROR_EMAIL_MEMBERS_FAILED'), 'error');
 		}
@@ -721,7 +655,7 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 		$xlog->action    = 'course_deleted';
 		$xlog->comments  = $log;
 		$xlog->actorid   = $this->juser->get('id');
-		if (!$xlog->store()) 
+		if (!$xlog->store())
 		{
 			$this->addComponentMessage($xlog->getError(), 'error');
 		}
@@ -729,14 +663,14 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 		// Redirect back to the courses page
 		$this->setRedirect(
 			JRoute::_('index.php?option=' . $this->_option),
-			JText::sprintf('You successfully deleted the "%s" course', $this->course->get('title')), 
+			JText::sprintf('COM_COURSES_COURSE_DELETED', $this->course->get('title')),
 			'passed'
 		);
 	}
 
 	/**
 	 * Change the status of an item
-	 * 
+	 *
 	 * @param      string $type   Item being changed
 	 * @param      string $status Status to set
 	 * @param      string $id     Item ID
@@ -748,9 +682,9 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 		JRequest::checkToken() or jexit('Invalid Token');
 
 		// Check if they're logged in
-		if ($this->juser->get('guest')) 
+		if ($this->juser->get('guest'))
 		{
-			$this->loginTask(JText::_('You must be logged in to perform this action.'));
+			$this->loginTask(JText::_('COM_COURSES_NOT_LOGGEDIN'));
 			return;
 		}
 
@@ -792,21 +726,21 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 		// Redirect back to the course page
 		$this->setRedirect(
 			JRoute::_($course->link()),
-			JText::_('Page successfully saved.')
+			JText::_('COM_COURSES_PAGE_SAVED')
 		);
 	}
 
 	/**
 	 * Change the status of an item
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function deletepageTask()
 	{
 		// Check if they're logged in
-		if ($this->juser->get('guest')) 
+		if ($this->juser->get('guest'))
 		{
-			$this->loginTask('You must be logged in to perform this action.');
+			$this->loginTask('COM_COURSES_NOT_LOGGEDIN');
 			return;
 		}
 
@@ -843,14 +777,14 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 		// Redirect back to the course page
 		$this->setRedirect(
 			JRoute::_($this->course->link()),
-			($msg ? $msg : JText::_('Page successfully removed.')),
+			($msg ? $msg : JText::_('COM_COURSES_PAGE_REMOVED')),
 			($msg ? 'error' : null)
 		);
 	}
 
 	/**
 	 * Check if a course alias is valid
-	 * 
+	 *
 	 * @param      integer $gid Course alias
 	 * @return     boolean True if valid, false if not
 	 */
@@ -858,24 +792,22 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 	{
 		if (preg_match("/^[0-9a-zA-Z]+[_0-9a-zA-Z]*$/i", $gid))
 		{
-			if (is_numeric($gid) && intval($gid) == $gid && $gid >= 0) 
+			if (is_numeric($gid) && intval($gid) == $gid && $gid >= 0)
 			{
 				return false;
-			} 
-			else 
+			}
+			else
 			{
 				return true;
 			}
-		} 
-		else 
-		{
-			return false;
 		}
+
+		return false;
 	}
 
 	/**
 	 * Generate a random string
-	 * 
+	 *
 	 * @param      integer $length Length of string
 	 * @return     string
 	 */
@@ -894,7 +826,7 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 
 	/**
 	 * Get a course's availability
-	 * 
+	 *
 	 * @param      object $course CoursesCourse
 	 * @return     string
 	 */
@@ -911,7 +843,7 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 
 		// Ensure the data passed is valid
 		$c = CoursesModelCourse::getInstance($course);
-		if (($course == 'new' || $course == 'browse') || !$this->_validCn($course) || $c->exists()) 
+		if (($course == 'new' || $course == 'browse') || !$this->_validCn($course) || $c->exists())
 		{
 			$availability = false;
 		}
@@ -933,7 +865,7 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 
 	/**
 	 * Download a wiki file
-	 * 
+	 *
 	 * @return     void
 	 */
 	public function downloadTask()
@@ -947,11 +879,11 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 
 		// Get the scope of the parent page the file is attached to
 		$filename = JRequest::getVar('file', '');
-		if (substr(strtolower($filename), 0, strlen('image:')) == 'image:') 
+		if (substr(strtolower($filename), 0, strlen('image:')) == 'image:')
 		{
 			$filename = substr($filename, strlen('image:'));
-		} 
-		else if (substr(strtolower($filename), 0, strlen('file:')) == 'file:') 
+		}
+		else if (substr(strtolower($filename), 0, strlen('file:')) == 'file:')
 		{
 			$filename = substr($filename, strlen('file:'));
 		}
@@ -964,11 +896,11 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 		$filename = DS . ltrim($filename, DS);
 
 		// Does the beginning of the $attachment->path match the config path?
-		if (substr($filename, 0, strlen($base_path)) == $base_path) 
+		if (substr($filename, 0, strlen($base_path)) == $base_path)
 		{
 			// Yes - this means the full path got saved at some point
-		} 
-		else 
+		}
+		else
 		{
 			// No - append it
 			$filename = $base_path . $filename;
@@ -978,7 +910,7 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 		$filename = JPATH_ROOT . $filename;
 
 		// Ensure the file exist
-		if (!file_exists($filename)) 
+		if (!file_exists($filename))
 		{
 			JError::raiseError(404, JText::_('COM_COURSES_FILE_NOT_FOUND').' '.$filename);
 			return;
@@ -990,12 +922,12 @@ class CoursesControllerCourse extends \Hubzero\Component\SiteController
 		$xserver->disposition('inline');
 		$xserver->acceptranges(false); // @TODO fix byte range support
 
-		if (!$xserver->serve()) 
+		if (!$xserver->serve())
 		{
 			// Should only get here on error
 			JError::raiseError(404, JText::_('COM_COURSES_SERVER_ERROR'));
-		} 
-		else 
+		}
+		else
 		{
 			exit;
 		}
