@@ -1,19 +1,21 @@
 <?php
 
+use Hubzero\Content\Migration\Base;
+
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
 /**
  * Migration script for add watching table
  **/
-class Migration20130512175301PlgCoursesDiscussions extends Hubzero_Migration
+class Migration20130512175301PlgCoursesDiscussions extends Base
 {
 	/**
 	 * Up
 	 **/
-	protected static function up($db)
+	public function up()
 	{
-		if (version_compare(JVERSION, '1.6', 'lt'))
+		if ($this->db->tableExists('#__plugins'))
 		{
 			$query = "UPDATE `#__plugins` SET `element`='discussions' WHERE `element`='forum' AND `folder`='courses';";
 		}
@@ -22,16 +24,16 @@ class Migration20130512175301PlgCoursesDiscussions extends Hubzero_Migration
 			$query = "UPDATE `#__extensions` SET `element`='discussions' WHERE `element`='forum' AND `folder`='courses';";
 		}
 
-		$db->setQuery($query);
-		$db->query();
+		$this->db->setQuery($query);
+		$this->db->query();
 	}
 
 	/**
 	 * Down
 	 **/
-	protected static function down($db)
+	public function down()
 	{
-		if (version_compare(JVERSION, '1.6', 'lt'))
+		if ($this->db->tableExists('#__plugins'))
 		{
 			$query = "UPDATE `#__plugins` SET `element`='forum' WHERE `element`='discussions' AND `folder`='courses';";
 		}
@@ -40,7 +42,7 @@ class Migration20130512175301PlgCoursesDiscussions extends Hubzero_Migration
 			$query = "UPDATE `#__extensions` SET `element`='forum' WHERE `element`='discussions' AND `folder`='courses';";
 		}
 
-		$db->setQuery($query);
-		$db->query();
+		$this->db->setQuery($query);
+		$this->db->query();
 	}
 }
\ No newline at end of file
